--[[
	Glyph Reporter
	
	Coded by Earl_Parvisjam

	This addon reports known and needed glyphs for all characters on the current server.
	
   ]]
   
GlyphReporter_Version = "1.01";
ReporterDB = {};
local realm = GetRealmName();
local player = UnitName("player");

---------------------------------------------------
-- OnLoad
---------------------------------------------------

function GlyphReporter_OnLoad(self)
	self:RegisterEvent("GLYPH_ENABLED");
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

---------------------------------------------------
-- OnEvent
---------------------------------------------------

function GlyphReporter_OnEvent(self, event)
	if (event == "PLAYER_ENTERING_WORLD") then
		if (ReporterDB[realm] == nil) then
			ReporterDB[realm] = {};
			ReporterDB[realm][player] = {};		
		end
	end
		GlyphReporter_GrabCurrentData();
end



---------------------------------------------------
-- GrabCurrentData
-- Summary:  Grabs all current Glyph info
---------------------------------------------------
function GlyphReporter_GrabCurrentData()
	local glyphList = {};
	if (GetNumGlyphs() > 0) then
		for index = 1, GetNumGlyphs() do
			local name, glyphType, isKnown = GetGlyphInfo(index);
			if (name ~= "header") then
				glyphList[name] = { ["Type"] = glyphType, ["Known"] = isKnown };
			end			
		end
	end
	local Player = { ["Glyphs"] = glyphList };
	ReporterDB[realm][player] = Player;
end

---------------------------------------------------
-- CheckNeed
-- Summary:  Grabs all needy characters
---------------------------------------------------
function GlyphReporter_CheckNeed(glyphName)
	local removeThe = string.sub(glyphName, 5);
	local needList = "Needed by:  ";
	GlyphReporter_GrabCurrentData();
	for currentPlayer, value in pairs(ReporterDB[GetRealmName()]) do
		if ((value["Glyphs"][glyphName] ~= nil) and (value["Glyphs"][glyphName]["Known"] == false)) then
				needList = needList ..currentPlayer;
		elseif ((value["Glyphs"][removeThe] ~= nil) and (value["Glyphs"][removeThe]["Known"] == false)) then
				needList = needList ..currentPlayer;
		end
	end
	return needList;
end

function GlyphReporter_Print(msg)
	if (msg == nil) then return; end
	if( DEFAULT_CHAT_FRAME ) then DEFAULT_CHAT_FRAME:AddMessage(msg, 1,1, 0); end
end

local setOnce = {};
---------------------------------------------------
-- ToolTipHooker
-- Summary:  Hooks extra text onto the tooltip
---------------------------------------------------
local function ToolTipHooker(self, ...)
	if (not setOnce[self]) then
		local itemLink = select(2, self:GetItem());
		if itemLink and GetItemInfo(itemLink) then
			local itemName, _, _, _, _, itemType = GetItemInfo(itemLink);
			if ("Glyph" == itemType) then
				local list = GlyphReporter_CheckNeed(string.sub(itemName, 10));
				self:AddLine(list, 1, 1, 1, 1);
				setOnce[self] = true;
			end

		end
	end
end

---------------------------------------------------
-- ToolTipUnHooker
-- Summary:  Unhooks extra text on the tooltip
---------------------------------------------------
local function ToolTipUnhooker(self, ...)
	setOnce[self] = false;
end

GameTooltip:HookScript("OnTooltipSetItem", ToolTipHooker);
GameTooltip:HookScript("OnTooltipCleared", ToolTipUnhooker);